aboutsummaryrefslogtreecommitdiffstats
path: root/erts/emulator/zlib/inftrees.h
diff options
context:
space:
mode:
authorBjörn Gustavsson <[email protected]>2014-01-09 12:26:18 +0100
committerBjörn Gustavsson <[email protected]>2014-01-14 09:30:34 +0100
commit9205b6671892e7516e8571e4ecf19bfa2ade1130 (patch)
treee2027206adefa16bdd3a323824986ef0719b4806 /erts/emulator/zlib/inftrees.h
parent069f9ec3dfd7a4dc17973e22dc271d40ebe11467 (diff)
downloadotp-9205b6671892e7516e8571e4ecf19bfa2ade1130.tar.gz
otp-9205b6671892e7516e8571e4ecf19bfa2ade1130.tar.bz2
otp-9205b6671892e7516e8571e4ecf19bfa2ade1130.zip
Update zlib to 1.2.8
Diffstat (limited to 'erts/emulator/zlib/inftrees.h')
-rw-r--r--erts/emulator/zlib/inftrees.h29
1 files changed, 17 insertions, 12 deletions
diff --git a/erts/emulator/zlib/inftrees.h b/erts/emulator/zlib/inftrees.h
index 808100f70a..baa53a0b1a 100644
--- a/erts/emulator/zlib/inftrees.h
+++ b/erts/emulator/zlib/inftrees.h
@@ -1,10 +1,8 @@
/* inftrees.h -- header to use inftrees.c
- * Copyright (C) 1995-2005 Mark Adler
+ * Copyright (C) 1995-2005, 2010 Mark Adler
* For conditions of distribution and use, see copyright notice in zlib.h
*/
-/* %ExternalCopyright% */
-
/* WARNING: this file should *not* be used by applications. It is
part of the implementation of the compression library and is
subject to change. Applications should only use zlib.h.
@@ -37,21 +35,28 @@ typedef struct {
01000000 - invalid code
*/
-/* Maximum size of dynamic tree. The maximum found in a long but non-
- exhaustive search was 1444 code structures (852 for length/literals
- and 592 for distances, the latter actually the result of an
- exhaustive search). The true maximum is not known, but the value
- below is more than safe. */
-#define ENOUGH 2048
-#define MAXD 592
+/* Maximum size of the dynamic table. The maximum number of code structures is
+ 1444, which is the sum of 852 for literal/length codes and 592 for distance
+ codes. These values were found by exhaustive searches using the program
+ examples/enough.c found in the zlib distribtution. The arguments to that
+ program are the number of symbols, the initial root table size, and the
+ maximum bit length of a code. "enough 286 9 15" for literal/length codes
+ returns returns 852, and "enough 30 6 15" for distance codes returns 592.
+ The initial root table size (9 or 6) is found in the fifth argument of the
+ inflate_table() calls in inflate.c and infback.c. If the root table size is
+ changed, then these maximum sizes would be need to be recalculated and
+ updated. */
+#define ENOUGH_LENS 852
+#define ENOUGH_DISTS 592
+#define ENOUGH (ENOUGH_LENS+ENOUGH_DISTS)
-/* Type of code to build for inftable() */
+/* Type of code to build for inflate_table() */
typedef enum {
CODES,
LENS,
DISTS
} codetype;
-extern int inflate_table OF((codetype type, unsigned short FAR *lens,
+int ZLIB_INTERNAL inflate_table OF((codetype type, unsigned short FAR *lens,
unsigned codes, code FAR * FAR *table,
unsigned FAR *bits, unsigned short FAR *work));